@@ -1,7 +1,7 @@
 from nonebot import get_driver, require
 
 
-from .bot import info,error,warn
+from .bot import info,error,warn,err
 from nonebot.plugin import on_command , on_message , on
 from nonebot.adapters.onebot.v11 import Bot, MessageSegment
 from nonebot.adapters import Message
@@ -10,7 +10,7 @@ from nonebot.plugin import PluginMetadata
 from nonebot.adapters.onebot.v11.event import GroupMessageEvent
 from nonebot.params import CommandArg
 from nonebot.rule import to_me
-from .bot import Chat,Bing,text2image,startup,Chat_api
+from .bot import Chat,Bing,text2image,startup,Chat_api,AIcheck
 
 from dotenv import dotenv_values, load_dotenv
 config =dotenv_values(".cfg")
@@ -31,20 +31,28 @@ async def do_something():
     global Presets
     global botList  
     global cfg
+    global ChatUse
     info('fthxbot','startup')
     CFGdata = await startup()
     Presets = CFGdata['Presets']
     botList = CFGdata['botList']
     cfg = CFGdata['cfg']
+    ChatUse = CFGdata['ChatUse']
+
     
 
 chat = on_command('chat')
 @chat.handle()
 async def _(event:GuildMessageEvent|GroupMessageEvent,args: Message = CommandArg()):
+    global ChatUse
     message = args.extract_plain_text()
-    await Chat(chat,message)
-    if type(event) == GuildMessageEvent:await Bing(bing,message)
-    elif type(event) == GroupMessageEvent:await Bing(bing,message,0)
+    if ChatUse == Bing:
+        if await AIcheck(Chat_api):
+            ChatUse = Chat_api
+        elif await AIcheck(Chat):
+            ChatUse = Chat
+    if type(event) == GuildMessageEvent:await ChatUse(bing,message) # type: ignore
+    elif type(event) == GroupMessageEvent:await ChatUse(bing,message,0) # type: ignore
 
 bing = on_command('bing')
 @bing.handle()
@@ -60,20 +68,6 @@ msg = on_message(rule=to_me())
 async def _(event:GuildMessageEvent|GroupMessageEvent):
     global ChatUse
     message = str(event.message)
-    All = {
-        'ChatGPT' : Chat,
-        'Bing' : Bing,
-        'ChatGPT_api' : Chat_api,
-    }
-    if cfg['defaultAI'] and type(cfg['defaultAI'])==str:  
-        if cfg.defaultAI in botList:
-            try : not ChatUse # type: ignore
-            except : ChatUse  = All[cfg['defaultAI']]
-        else: 
-            return error('Config','你配置的 defaultAI 没有被接入')
-    else: 
-        return error('Config','你没有配置 defaultAI')
-
     if type(event) == GuildMessageEvent:await ChatUse(msg,message) # type: ignore
     elif type(event) == GroupMessageEvent:await ChatUse(msg,message,0) # type: ignore
 
@@ -82,22 +76,19 @@ tag = on_command('tag')
 @tag.handle()
 async def _(args: Message = CommandArg()):
     message = args.extract_plain_text()
-    await Chat(tag,Presets['PromptGenerator'] + message,0)
+    global ChatUse
+    await ChatUse(tag,Presets['PromptGenerator'] + message,0) # type: ignore
 
 
 ai = on_command('ai')
 @ai.handle()
 async def _(args: Message = CommandArg()):
     message = args.extract_plain_text()
-    text = await Chat(tag,Presets['PromptGenerator'] + message,2)
+    global ChatUse
+    text = await ChatUse(tag,Presets['PromptGenerator'] + message,2) # type: ignore
     img_bytes = await text2image(ai,text)
     await ai.reject(MessageSegment.image(file=img_bytes,cache=False))
 
-test = on_command('test')
-@test.handle()
-async def _():
-    await test.send('test')
-
 chatC = on_command('切换AI')
 @chatC.handle()
 async def _(args: Message = CommandArg()):
@@ -106,11 +97,11 @@ async def _(args: Message = CommandArg()):
         'Bing' : Bing,
         'ChatGPT_api' : Chat_api,
     }
-    global chatUse
     message = args.extract_plain_text()
-    if message in botList:
-        chatUse = All[message]
-        await chatC.send(f'已切换到 {message}')
-    else: 
-        await chatC.send('AI没有配置 或 AI不存在')
+    global ChatUse
+    ChatUse = All[message]
+    if not await AIcheck(ChatUse) :
+        err('ChatUse','AI不存在')
+        return await chatC.send('AI不存在')
+    await chatC.send(f'已切换到 {message}')
 
